Crate lightyear_utils

Crate lightyear_utils 

Contains a set of useful utilities

Modules

captures
Captures trick to allow for better impl Iterator + ’a See <https://rust-lang.github.io/rfcs/3498-lifetime-capture-rules-2024.html> and <https://www.youtube.com/watch?v=CWiz_RtA1Hw>
collections
ecs
Helpers for low-level ECS operations.
free_list
metrics
ready_buffer
Wrapper around a min-heap
registry
sequence_buffer
Wrapper around a list where the index is a wrapping key
wrapping_id
u32 identifier with wrapping sequence-number arithmetic.

Macros

adaptive_for_each_mut
Iterates a mutable query serially when it contains at most a small number of items, and in parallel otherwise.
dormant_timer_gauge
Creates a dormant DormantTimerGauge from a metric-name prefix.
timer_gauge
Creates a TimerGauge from a metric-name prefix.
wrapping_id
Index that wraps around 2^32